@@ -10,15 +10,18 @@ use terminal::util::Size;
 const MAX_GRID_SIZE: u16 = 99;
 
 /// The values that can be created out of the arguments.
+#[derive(Debug)]
 pub enum Arg {
     File { name: String, content: String },
     GridSize(Size),
     Help,
+    Version,
 }
 
+#[derive(Debug)]
 enum SizeError {
     OutOfRange(&'static str),
-    Other(&'static str),
+    FileNotFound,
 }
 
 fn parse_squared_size(size_str: &str) -> Result<Option<Arg>, SizeError> {
@@ -34,7 +37,7 @@ fn parse_squared_size(size_str: &str) -> Result<Option<Arg>, SizeError> {
         // A value >u16::MAX will not parse but might still be a number
         Err(SizeError::OutOfRange("size"))
     } else {
-        Err(SizeError::Other("file not found"))
+        Err(SizeError::FileNotFound)
     }
 }
 
@@ -60,7 +63,7 @@ fn parse_size(width_str: &str, height_str: &str) -> Result<Option<Arg>, SizeErro
         return Err(SizeError::OutOfRange("width"));
     }
 
-    Err(SizeError::Other("file not found"))
+    Err(SizeError::FileNotFound)
 }
 
 fn parse_strings(
@@ -83,10 +86,10 @@ fn parse_strings(
             }
 
             if !valid_extension(&first_string) {
-                return Err("filename extension must be \"yaya\"".into());
+                return Err("Filename extension must be \"yaya\"".into());
             }
 
-            let content = util::read_file_content(&mut file).map_err(|_| "file reading error")?;
+            let content = util::read_file_content(&mut file).map_err(|_| "File reading error")?;
 
             Ok(Some(Arg::File {
                 name: first_string,
@@ -97,6 +100,8 @@ fn parse_strings(
             io::ErrorKind::NotFound => {
                 if first_string == "--help" || first_string == "-h" {
                     Ok(Some(Arg::Help))
+                } else if first_string == "--version" || first_string == "-V" {
+                    Ok(Some(Arg::Version))
                 } else {
                     let result = if let Some(second_string) = second_string {
                         parse_size(&first_string, &second_string)
@@ -107,15 +112,15 @@ fn parse_strings(
                     match result {
                         Ok(size) => Ok(size),
                         Err(SizeError::OutOfRange(thing)) => Err(format!(
-                            "grid {} must be in range 1 to {}",
+                            "Grid {} must be in range 1 to {}",
                             thing, MAX_GRID_SIZE
                         )
                         .into()),
-                        Err(SizeError::Other(message)) => Err(message.into()),
+                        Err(SizeError::FileNotFound) => Err("File not found".into()),
                     }
                 }
             }
-            _ => Err("file opening error".into()),
+            _ => Err("File opening error".into()),
         },
     }
 }
@@ -133,15 +138,85 @@ pub fn parse() -> Result<Option<Arg>, Cow<'static, str>> {
                 if let Ok(second_string) = arg.into_string() {
                     parse_strings(first_string, Some(second_string))
                 } else {
-                    Err("second argument is not valid UTF-8".into())
+                    Err("Second argument is not valid UTF-8".into())
                 }
             } else {
                 parse_strings(first_string, None)
             }
         } else {
-            Err("first argument is not valid UTF-8".into())
+            Err("First argument is not valid UTF-8".into())
         }
     } else {
         Ok(None)
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_parse_strings() {
+        assert!(matches!(
+            parse_strings(String::from("example.yaya"), None),
+            Ok(Some(Arg::File {
+                name: _,
+                content: _
+            }))
+        ));
+    }
+
+    #[test]
+    fn test_parse_squared_size() {
+        assert!(matches!(
+            parse_squared_size("99"),
+            Ok(Some(Arg::GridSize(Size {
+                width: 99,
+                height: 99
+            })))
+        ));
+
+        assert!(!matches!(
+            parse_squared_size("100"),
+            Ok(Some(Arg::GridSize(Size {
+                width: 100,
+                height: 100
+            })))
+        ));
+
+        assert!(!matches!(
+            parse_squared_size("0"),
+            Ok(Some(Arg::GridSize(Size {
+                width: 0,
+                height: 0
+            })))
+        ));
+    }
+
+    #[test]
+    fn test_parse_size() {
+        assert!(matches!(
+            parse_size("25", "50"),
+            Ok(Some(Arg::GridSize(Size {
+                width: 25,
+                height: 50
+            })))
+        ));
+
+        assert!(!matches!(
+            parse_size("100", "99"),
+            Ok(Some(Arg::GridSize(Size {
+                width: 100,
+                height: 99
+            })))
+        ));
+
+        assert!(!matches!(
+            parse_size("0", "0"),
+            Ok(Some(Arg::GridSize(Size {
+                width: 0,
+                height: 0
+            })))
+        ));
+    }
+}
